macro_rules! error {
($fmt:expr) => { ... };
}Expand description
Logs an error message.
This macro logs a message at the ERROR level with red coloring. Error messages indicate serious problems that prevent normal operation.
macro_rules! error {
($fmt:expr) => { ... };
}Logs an error message.
This macro logs a message at the ERROR level with red coloring. Error messages indicate serious problems that prevent normal operation.