macro_rules! red {
($fmt:expr) => { ... };
}Expand description
Formats text in red.
This macro wraps text in ANSI escape sequences to make it appear red in terminal output.
macro_rules! red {
($fmt:expr) => { ... };
}Formats text in red.
This macro wraps text in ANSI escape sequences to make it appear red in terminal output.