macro_rules! red_start {
() => { ... };
}Expand description
Starts red text coloring.
This macro outputs the ANSI escape sequence to start red text, without resetting the color afterward.
macro_rules! red_start {
() => { ... };
}Starts red text coloring.
This macro outputs the ANSI escape sequence to start red text, without resetting the color afterward.