macro_rules! yellow_start {
() => { ... };
}Expand description
Starts yellow text coloring.
This macro outputs the ANSI escape sequence to start yellow text, without resetting the color afterward.
macro_rules! yellow_start {
() => { ... };
}Starts yellow text coloring.
This macro outputs the ANSI escape sequence to start yellow text, without resetting the color afterward.